@@ -7,7 +7,7 @@
  * The CHOLMOD/Tcov Module is licensed under Version 2.0 of the GNU
  * General Public License.  See gpl.txt for a text of the license.
  * CHOLMOD is also available under other licenses; contact authors for details.
- * http://www.cise.ufl.edu/research/sparse
+ * http://www.suitesparse.com
  * -------------------------------------------------------------------------- */
 
 /* A program for exhaustive statement-coverage for CHOLMOD, AMD, COLAMD, and
@@ -1285,10 +1285,10 @@ double do_matrix (cholmod_sparse *A)
 
 	    printf ("test_solver (2)\n") ;
 	    cm->final_asis = TRUE ;
-	    cm->method [0].ordering = CHOLMOD_NATURAL ;
 	    for (nmethods = 0 ; nmethods < 7 ; nmethods++)
 	    {
 		cm->nmethods = nmethods ;
+	        cm->method [0].ordering = CHOLMOD_NATURAL ;
 		err = test_solver (A) ;				/* RAND reset */
 		MAXERR (maxerr, err, 1) ;
 	    }
@@ -1367,8 +1367,13 @@ int main (int argc, char **argv)
     Int n = 0, nmin = 0, nrow = 0, ncol = 0, save ;
     int singular, do_memory, i, do_nantests ;
     double v = CHOLMOD_VERSION ;
+    int version [3] ;
 
-    printf ("Testing CHOLMOD (%g)\n", v) ;
+    printf ("Testing CHOLMOD (%g): %d ", v, CHOLMOD(version) (version)) ;
+    printf ("(%d.%d.%d)\n", version [0], version [1], version [2]) ;
+    v = SUITESPARSE_VERSION ;
+    printf ("for SuiteSparse (%g): %d ", v, SuiteSparse_version (version)) ;
+    printf ("(%d.%d.%d)\n", version [0], version [1], version [2]) ;
     printf ("%s: argc: %d\n", argv [0], argc) ;
     my_srand (42) ;						/* RAND */
     fflush (stdout) ;
@@ -1438,8 +1443,11 @@ int main (int argc, char **argv)
 
 	if (T->nrow > 1000000)
 	{
-	    /* do huge-problem tests only */
-	    huge ( ) ;
+	    /* do huge-problem tests only, but only for 32-bit systems */
+            if (sizeof (Int) == sizeof (int))
+            {
+                huge ( ) ;
+            }
 	    CHOLMOD(free_triplet) (&T, cm) ;
 	    continue ;
 	}
