@@ -5,9 +5,7 @@ function test1
 %   test1
 % See also: testall
 
-%   Copyright 2006-2007, Timothy A. Davis.
-%   http://www.cise.ufl.edu/research/sparse
-
+% Copyright 2006-2012, Timothy A. Davis, http://www.suitesparse.com
 
 index = UFget ;
 [ignore f] = sort (max (index.nrows, index.ncols)) ;
@@ -46,6 +44,13 @@ for ii = f
     i = i (p) ;
     j = j (p) ;
     x = x (p) ;
+    if (m == 1)
+        % find returns rows vectors if A is 1-by-n,
+        % but cs_sparse requires column vectors
+        i = i (:) ;
+        j = j (:) ;
+        x = x (:) ;
+    end
     D = sparse (i,j,x) ;
     E = cs_sparse (i,j,x) ;
     % [i j x]
