@@ -48,6 +48,7 @@
 
 #include "klu.h"
 #include <string.h>
+#define Long SuiteSparse_long
 
 #ifndef NCHOLMOD
 #include "klu_cholmod.h"
@@ -111,7 +112,7 @@ void mexFunction
     double ukk, lkk, rs, s, lik, uik, x [4], offik, z, ukkz, lkkz, sz, wx, wz ;
     double *X, *B, *Xz, *Xx, *Bx, *Bz, *A, *Ax, *Az, *Lx, *Ux, *Rs, *Offx, *Wx,
         *Uz, *Lz, *Offz, *Wz, *W, *Xi, *Bi ;
-    UF_long *Ap, *Ai, *Lp, *Li, *Up, *Ui, *P, *Q, *R, *Rp, *Ri, *Offp, *Offi ;
+    Long *Ap, *Ai, *Lp, *Li, *Up, *Ui, *P, *Q, *R, *Rp, *Ri, *Offp, *Offi ;
     char *operator ;
     mxArray *L_matlab, *U_matlab, *p_matlab, *q_matlab, *R_matlab, *F_matlab,
         *r_matlab, *field ;
@@ -119,7 +120,7 @@ void mexFunction
     klu_l_symbolic *Symbolic ;
     klu_l_numeric *Numeric ;
     klu_l_common Common ;
-    UF_long n = 0, k, nrhs = 0, do_solve, do_factorize, symmetric,
+    Long n = 0, k, nrhs = 0, do_solve, do_factorize, symmetric,
         A_complex = 0, B_complex, nz, do_transpose = 0, p, pend, nblocks,
         R1 [2], chunk, nr, i, j, block, k1, k2, nk, bn = 0, ordering ;
     int mx_int ;
@@ -154,7 +155,7 @@ void mexFunction
     do_solve = (nargin > 2) ;
 
     /* determine size of the MATLAB integer */
-    if (sizeof (UF_long) == sizeof (INT32_T))
+    if (sizeof (Long) == sizeof (INT32_T))
     {
         mx_int = mxINT32_CLASS ;
     }
@@ -334,8 +335,8 @@ void mexFunction
             mexErrMsgTxt ("A must be sparse, square, and non-empty") ;
         }
 
-        Ap = (UF_long *) mxGetJc (A_matlab) ;
-        Ai = (UF_long *) mxGetIr (A_matlab) ;
+        Ap = (Long *) mxGetJc (A_matlab) ;
+        Ai = (Long *) mxGetIr (A_matlab) ;
         Ax = mxGetPr (A_matlab) ;
         Az = mxGetPi (A_matlab) ;
         nz = Ap [n] ;
@@ -412,7 +413,7 @@ void mexFunction
         /* ------------------------------------------------------------------ */
 
 #define INFO(i,x) \
-        mxSetFieldByNumber (pargout [1], 0, i, mxCreateScalarDouble (x))
+        mxSetFieldByNumber (pargout [1], 0, i, mxCreateDoubleScalar (x))
 
         if (nargout > 1)
         {
@@ -570,7 +571,7 @@ void mexFunction
                     {
 
                         /* A is real: real(X) = real(b) / real(A) */
-                        UF_long chunksize = MIN (nrhs - chunk, 4) ;
+                        Long chunksize = MIN (nrhs - chunk, 4) ;
                         for (j = 0 ; j < chunksize ; j++)
                         {
                             for (i = 0 ; i < n ; i++)
@@ -705,8 +706,8 @@ void mexFunction
                 mexErrMsgTxt ("LU.L must be sparse and same size as A") ;
             }
 
-            Lp = (UF_long *) mxGetJc (L_matlab) ;
-            Li = (UF_long *) mxGetIr (L_matlab) ;
+            Lp = (Long *) mxGetJc (L_matlab) ;
+            Li = (Long *) mxGetIr (L_matlab) ;
             Lx = mxGetPr (L_matlab) ;
             Lz = mxGetPi (L_matlab) ;
 
@@ -716,8 +717,8 @@ void mexFunction
             {
                 mexErrMsgTxt ("LU.U must be sparse and same size as A") ;
             }
-            Up = (UF_long *) mxGetJc (U_matlab) ;
-            Ui = (UF_long *) mxGetIr (U_matlab) ;
+            Up = (Long *) mxGetJc (U_matlab) ;
+            Ui = (Long *) mxGetIr (U_matlab) ;
             Ux = mxGetPr (U_matlab) ;
             Uz = mxGetPi (U_matlab) ;
 
@@ -730,7 +731,7 @@ void mexFunction
                 {
                     mexErrMsgTxt ("P invalid") ;
                 }
-                P = (UF_long *) mxGetData (p_matlab) ;
+                P = (Long *) mxGetData (p_matlab) ;
                 for (k = 0 ; k < n ; k++)
                 {
                     if (P [k] < 1 || P [k] > n) mexErrMsgTxt ("P invalid") ;
@@ -751,7 +752,7 @@ void mexFunction
                 {
                     mexErrMsgTxt ("Q invalid") ;
                 }
-                Q = (UF_long *) mxGetData (q_matlab) ;
+                Q = (Long *) mxGetData (q_matlab) ;
                 for (k = 0 ; k < n ; k++)
                 {
                     if (Q [k] < 1 || Q [k] > n) mexErrMsgTxt ("Q invalid.") ;
@@ -774,7 +775,7 @@ void mexFunction
                 {
                     mexErrMsgTxt ("r invalid") ;
                 }
-                R = (UF_long *) mxGetData (r_matlab) ;
+                R = (Long *) mxGetData (r_matlab) ;
                 if (R [0] != 1) mexErrMsgTxt ("r invalid") ;
                 for (k = 1 ; k <= nblocks ; k++)
                 {
@@ -801,7 +802,7 @@ void mexFunction
                 {
                     mexErrMsgTxt ("LU.R must be sparse and same size as A") ;
                 }
-                Rp = (UF_long *) mxGetJc (R_matlab) ;
+                Rp = (Long *) mxGetJc (R_matlab) ;
                 Rs = mxGetPr (R_matlab) ;
                 if (Rp [n] != n)
                 {
@@ -822,8 +823,8 @@ void mexFunction
                 {
                     mexErrMsgTxt ("LU.F must be sparse and same size as A") ;
                 }
-                Offp = (UF_long *) mxGetJc (F_matlab) ;
-                Offi = (UF_long *) mxGetIr (F_matlab) ;
+                Offp = (Long *) mxGetJc (F_matlab) ;
+                Offi = (Long *) mxGetIr (F_matlab) ;
                 Offx = mxGetPr (F_matlab) ;
                 Offz = mxGetPi (F_matlab) ;
             }
@@ -1889,31 +1890,31 @@ void mexFunction
         /* L */
         L_matlab = mxCreateSparse (n, n, Numeric->lnz,
             A_complex ? mxCOMPLEX: mxREAL) ;
-        Lp = (UF_long *) mxGetJc (L_matlab) ;
-        Li = (UF_long *) mxGetIr (L_matlab) ;
+        Lp = (Long *) mxGetJc (L_matlab) ;
+        Li = (Long *) mxGetIr (L_matlab) ;
         Lx = mxGetPr (L_matlab) ;
         Lz = mxGetPi (L_matlab) ;
 
         /* U */
         U_matlab = mxCreateSparse (n, n, Numeric->unz,
             A_complex ? mxCOMPLEX: mxREAL) ;
-        Up = (UF_long *) mxGetJc (U_matlab) ;
-        Ui = (UF_long *) mxGetIr (U_matlab) ;
+        Up = (Long *) mxGetJc (U_matlab) ;
+        Ui = (Long *) mxGetIr (U_matlab) ;
         Ux = mxGetPr (U_matlab) ;
         Uz = mxGetPi (U_matlab) ;
 
         /* p */
         p_matlab = mxCreateNumericMatrix (1, n, mx_int, mxREAL) ;
-        P = (UF_long *) mxGetData (p_matlab) ;
+        P = (Long *) mxGetData (p_matlab) ;
 
         /* q */
         q_matlab = mxCreateNumericMatrix (1, n, mx_int, mxREAL) ;
-        Q = (UF_long *) mxGetData (q_matlab) ;
+        Q = (Long *) mxGetData (q_matlab) ;
 
         /* R, as a sparse diagonal matrix */
         R_matlab = mxCreateSparse (n, n, n+1, mxREAL) ;
-        Rp = (UF_long *) mxGetJc (R_matlab) ;
-        Ri = (UF_long *) mxGetIr (R_matlab) ;
+        Rp = (Long *) mxGetJc (R_matlab) ;
+        Ri = (Long *) mxGetIr (R_matlab) ;
         Rs = mxGetPr (R_matlab) ;
         for (k = 0 ; k <= n ; k++)
         {
@@ -1924,15 +1925,15 @@ void mexFunction
         /* F, off diagonal blocks */
         F_matlab = mxCreateSparse (n, n, Numeric->nzoff,
             A_complex ? mxCOMPLEX: mxREAL) ;
-        Offp = (UF_long *) mxGetJc (F_matlab) ;
-        Offi = (UF_long *) mxGetIr (F_matlab) ;
+        Offp = (Long *) mxGetJc (F_matlab) ;
+        Offi = (Long *) mxGetIr (F_matlab) ;
         Offx = mxGetPr (F_matlab) ;
         Offz = mxGetPi (F_matlab) ;
 
         /* r, block boundaries */
         nblocks = Symbolic->nblocks ;
         r_matlab = mxCreateNumericMatrix (1, nblocks+1, mx_int, mxREAL) ;
-        R = (UF_long *) mxGetData (r_matlab) ;
+        R = (Long *) mxGetData (r_matlab) ;
 
         /* extract the LU factorization from KLU Numeric and Symbolic objects */
         if (A_complex)
