@@ -3,9 +3,9 @@
 #define SPOK_INT mwSignedIndex
 #else
 /* for use outside of MATLAB, use with -DSPOK_INT=long to get long version of
-   code */
+   code, -DSPOK_INT=int for int version, etc */
 #ifndef SPOK_INT
-#define SPOK_INT int
+#define SPOK_INT ptrdiff_t
 #endif
 #endif
 
