@@ -49,12 +49,11 @@ SuiteSparseQR_factorization <Entry> *SuiteSparseQR_symbolic
     cholmod_common *cc      // workspace and parameters
 )
 {
-#ifdef TIMING
-    double t0 = spqr_time ( ) ;
-#endif
+    double t0 = SuiteSparse_time ( ) ;
+
     RETURN_IF_NULL_COMMON (NULL) ;
     RETURN_IF_NULL (A, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (A, NULL) ;
     cc->status = CHOLMOD_OK ;
 
@@ -119,10 +118,10 @@ SuiteSparseQR_factorization <Entry> *SuiteSparseQR_symbolic
 
     if (QRsym->Qfill != NULL)
     {
-        Int n, k, *Qfill, *Q1fill ;
+        Long n, k, *Qfill, *Q1fill ;
         Qfill = QRsym->Qfill ;
         n = A->ncol ;
-        Q1fill = (Int *) cholmod_l_malloc (n, sizeof (Int), cc) ;
+        Q1fill = (Long *) cholmod_l_malloc (n, sizeof (Long), cc) ;
         QR->Q1fill = Q1fill ;
         if (cc->status < CHOLMOD_OK)
         {
@@ -136,10 +135,8 @@ SuiteSparseQR_factorization <Entry> *SuiteSparseQR_symbolic
         }
     }
 
-#ifdef TIMING
-    double t1 = spqr_time ( ) ;
+    double t1 = SuiteSparse_time ( ) ;
     cc->other1 [1] = t1 - t0 ;
-#endif
 
     return (QR) ;
 }
@@ -174,6 +171,8 @@ SuiteSparseQR_factorization <Complex> *SuiteSparseQR_symbolic <Complex>
 // SuiteSparseQR_symbolic.  Alternatively, if SuiteSparseQR_factorize
 // did not find any singletons (QR->n1cols == 0), a call to
 // SuiteSparseQR_factorize can be followed by a factorization by this function.
+//
+// Returns TRUE if successful, FALSE otherwise.
 
 template <typename Entry> int SuiteSparseQR_numeric
 (
@@ -185,13 +184,12 @@ template <typename Entry> int SuiteSparseQR_numeric
     cholmod_common *cc      // workspace and parameters
 )
 {
-#ifdef TIMING
-    double t0 = spqr_time ( ) ;
-#endif
+    double t0 = SuiteSparse_time ( ) ;
+
     RETURN_IF_NULL_COMMON (FALSE) ;
     RETURN_IF_NULL (A, FALSE) ;
     RETURN_IF_NULL (QR, FALSE) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (A, FALSE) ;
     cc->status = CHOLMOD_OK ;
 
@@ -203,7 +201,7 @@ template <typename Entry> int SuiteSparseQR_numeric
         return (FALSE) ;
     }
 
-    Int n = A->ncol ;
+    Long n = A->ncol ;
 
     // -------------------------------------------------------------------------
     // get the column 2-norm tolerance
@@ -261,10 +259,8 @@ template <typename Entry> int SuiteSparseQR_numeric
     cc->SPQR_istat [4] = QR->rank ;         // estimated rank of A
     cc->SPQR_xstat [1] = tol ;              // tol used
 
-#ifdef TIMING
-    double t1 = spqr_time ( ) ;
+    double t1 = SuiteSparse_time ( ) ;
     cc->other1 [2] = t1 - t0 ;
-#endif
 
     return (TRUE) ;
 }
@@ -323,7 +319,7 @@ SuiteSparseQR_factorization <Entry> *SuiteSparseQR_factorize
 {
     RETURN_IF_NULL_COMMON (NULL) ;
     RETURN_IF_NULL (A, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (A, NULL) ;
     cc->status = CHOLMOD_OK ;
     // B is not present, and always keep H:
@@ -366,8 +362,8 @@ template <typename Entry> void spqr_private_rtsolve
     SuiteSparseQR_factorization <Entry> *QR,
     int use_Q1fill,
 
-    Int nrhs,               // number of columns of B
-    Int ldb,                // leading dimension of B
+    Long nrhs,              // number of columns of B
+    Long ldb,               // leading dimension of B
     Entry *B,               // size n-by-nrhs with leading dimension ldb
 
     // output, contents undefined on input
@@ -379,11 +375,11 @@ template <typename Entry> void spqr_private_rtsolve
     Entry xi ;
     spqr_symbolic *QRsym ;
     spqr_numeric <Entry> *QRnum ;
-    Int *R1p, *R1j, *Rmap, *Rp, *Rj, *Super, *HStair, *Hm, *Stair, *Q1fill,
+    Long *R1p, *R1j, *Rmap, *Rp, *Rj, *Super, *HStair, *Hm, *Stair, *Q1fill,
         *RmapInv ;
     Entry *R1x, **Rblock, *R, *X1, *X2 ;
     char *Rdead ;
-    Int i, j, k, m, n, p, kk, n1rows, n1cols, rank, nf, f, col1, col2, fp, pr,
+    Long i, j, k, m, n, p, kk, n1rows, n1cols, rank, nf, f, col1, col2, fp, pr,
         fn, rm, row1, keepH, fm, h, t, live, jj ;
 
     // -------------------------------------------------------------------------
@@ -459,7 +455,7 @@ template <typename Entry> void spqr_private_rtsolve
             {
                 k = RmapInv [i] ;
                 ASSERT (k >= 0 && k < n) ;
-                Int knew = Q1fill ? Q1fill [k] : k ;
+                Long knew = Q1fill ? Q1fill [k] : k ;
                 ASSERT (knew >= 0 && knew < n) ;
                 X1 [i] = B [knew] ;
             }
@@ -614,7 +610,7 @@ template <typename Entry> void spqr_private_rtsolve
             jj = j + n1cols ;
             if (jj >= n) break ;            // in case [A Binput] was factorized
 
-            Int ii = Rmap ? Rmap [jj] : jj ;
+            Long ii = Rmap ? Rmap [jj] : jj ;
             ASSERT (ii >= n1rows && ii < n) ;
             if (ii < rank)
             {
@@ -683,7 +679,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_solve    // returns X
 {
     Entry *Bx ;
     cholmod_dense *W, *X ;
-    Int m, n, nrhs, ldb, ok ;
+    Long m, n, nrhs, ldb, ok ;
 
     // -------------------------------------------------------------------------
     // get inputs
@@ -691,7 +687,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_solve    // returns X
 
     RETURN_IF_NULL_COMMON (NULL) ;
     RETURN_IF_NULL (B, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (B, NULL) ;
     RETURN_IF_NULL (QR, NULL) ;
     RETURN_IF_NULL (QR->QRnum, NULL) ;
@@ -702,7 +698,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_solve    // returns X
     }
     m = QR->narows ;
     n = QR->nacols ;
-    if ((Int) B->nrow != ((system <= SPQR_RETX_EQUALS_B) ? m : n))
+    if ((Long) B->nrow != ((system <= SPQR_RETX_EQUALS_B) ? m : n))
     {
         ERROR (CHOLMOD_INVALID, "invalid dimensions") ;
         return (NULL) ;
@@ -723,12 +719,12 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_solve    // returns X
         // X = E*(R\B) or X=R\B
         // ---------------------------------------------------------------------
 
-        Int *Rlive ;
+        Long *Rlive ;
         Entry **Rcolp ;
         X = cholmod_l_allocate_dense (n, nrhs, n, xtype, cc) ;
-        Int maxfrank = QR->QRnum->maxfrank  ;
+        Long maxfrank = QR->QRnum->maxfrank  ;
         W = cholmod_l_allocate_dense (maxfrank, nrhs, maxfrank, xtype, cc) ;
-        Rlive = (Int *)    cholmod_l_malloc (maxfrank, sizeof (Int),     cc) ;
+        Rlive = (Long *)   cholmod_l_malloc (maxfrank, sizeof (Long),    cc) ;
         Rcolp = (Entry **) cholmod_l_malloc (maxfrank, sizeof (Entry *), cc) ;
         ok = (X != NULL) && (W != NULL) && (cc->status == CHOLMOD_OK) ;
         if (ok)
@@ -736,7 +732,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_solve    // returns X
             spqr_rsolve (QR, system == SPQR_RETX_EQUALS_B, nrhs, ldb, Bx,
                 (Entry *) X->x, Rcolp, Rlive, (Entry *) W->x, cc) ;
         }
-        cholmod_l_free (maxfrank, sizeof (Int),     Rlive, cc) ;
+        cholmod_l_free (maxfrank, sizeof (Long),    Rlive, cc) ;
         cholmod_l_free (maxfrank, sizeof (Entry *), Rcolp, cc) ;
         cholmod_l_free_dense (&W, cc) ;
 
@@ -809,7 +805,7 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_solve    // returns X
     RETURN_IF_NULL_COMMON (NULL) ;
     RETURN_IF_NULL (QR, NULL) ;
     RETURN_IF_NULL (Bsparse, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (Bsparse, NULL) ;
     cc->status = CHOLMOD_OK ;
 
@@ -854,24 +850,24 @@ template cholmod_sparse *SuiteSparseQR_solve <Complex>
 // Get pointers to the Householder vectors in a single front.
 // Returns # Householder vectors in F.
 
-template <typename Entry> Int spqr_private_get_H_vectors
+template <typename Entry> Long spqr_private_get_H_vectors
 (
     // inputs
-    Int f,                  // front to operate on
+    Long f,                 // front to operate on
     SuiteSparseQR_factorization <Entry> *QR,
 
     // outputs
     Entry *H_Tau,           // size QRsym->maxfn
-    Int *H_start,           // size QRsym->maxfn
-    Int *H_end,             // size QRsym->maxfn
+    Long *H_start,          // size QRsym->maxfn
+    Long *H_end,            // size QRsym->maxfn
     cholmod_common *cc
 )
 {
     spqr_symbolic *QRsym ;
     spqr_numeric <Entry> *QRnum ;
     Entry *Tau ;
-    Int *Rj, *Stair ;
-    Int col1, col2, fp, pr, fn, fm, h, nh, p, rm, k, j, t, n1cols, n ;
+    Long *Rj, *Stair ;
+    Long col1, col2, fp, pr, fn, fm, h, nh, p, rm, k, j, t, n1cols, n ;
 
     // -------------------------------------------------------------------------
     // get the R block for front F
@@ -953,13 +949,13 @@ template <typename Entry> Int spqr_private_get_H_vectors
 
 // Load Householder vectors h1:h2-1 into the panel V.  Return # of rows in V.
 
-template <typename Entry> Int spqr_private_load_H_vectors
+template <typename Entry> Long spqr_private_load_H_vectors
 (
     // input
-    Int h1,             // load vectors h1 to h2-1
-    Int h2,
-    Int *H_start,       // vector h starts at R [H_start [h]]
-    Int *H_end,         // vector h ends at R [H_end [h]-1]
+    Long h1,            // load vectors h1 to h2-1
+    Long h2,
+    Long *H_start,      // vector h starts at R [H_start [h]]
+    Long *H_end,        // vector h ends at R [H_end [h]-1]
     Entry *R,           // Rblock [f]
     // output
     Entry *V,           // V is v-by-(h2-h1) and lower triangular
@@ -967,16 +963,16 @@ template <typename Entry> Int spqr_private_load_H_vectors
 )
 {
     // v = length of last H vector
-    Int v = H_end [h2-1] - H_start [h2-1] + (h2-h1) ;
+    Long v = H_end [h2-1] - H_start [h2-1] + (h2-h1) ;
     Entry *V1 = V ;
-    for (Int h = h1 ; h < h2 ; h++)
+    for (Long h = h1 ; h < h2 ; h++)
     {
-        Int i ;
+        Long i ;
         // This part of V is not accessed, for testing only:
         // for (i = 0 ; i < h-h1 ; i++) V1 [i] = 0 ;
         i = h-h1 ;
         V1 [i++] = 1 ;
-        for (Int p = H_start [h] ; p < H_end [h] ; p++)
+        for (Long p = H_start [h] ; p < H_end [h] ; p++)
         {
             V1 [i++] = R [p] ;
         }
@@ -1002,18 +998,18 @@ template <typename Entry> void spqr_private_Happly
     // inputs
     int method,             // 0,1,2,3
     SuiteSparseQR_factorization <Entry> *QR,
-    Int hchunk,             // apply hchunk Householder vectors at a time
+    Long hchunk,            // apply hchunk Householder vectors at a time
 
     // input/output
-    Int m,
-    Int n,
+    Long m,
+    Long n,
     Entry *X,               // size m-by-n with leading dimension m; only
                             // X (n1rows:m-1,:) or X (:,n1rows:n-1) is modified
 
     // workspace, not defined on input or output
     Entry *H_Tau,           // size QRsym->maxfn
-    Int *H_start,           // size QRsym->maxfn
-    Int *H_end,             // size QRsym->maxfn
+    Long *H_start,          // size QRsym->maxfn
+    Long *H_end,            // size QRsym->maxfn
     Entry *V,               // size v-by-hchunk, where v = QRnum->maxfm
     Entry *C,               // size: method 0,1: v*n,     method 2,3: m*v
     Entry *W,               // size: method 0,1: h*h+n*h, method 2,3: h*h+m*h
@@ -1025,8 +1021,8 @@ template <typename Entry> void spqr_private_Happly
     spqr_symbolic *QRsym ;
     spqr_numeric <Entry> *QRnum ;
     Entry **Rblock, *R, *X2 ;
-    Int *Hii, *Hip, *Hi ;
-    Int nf, f, nh, h1, h2, v, n1rows, m2, n2 ;
+    Long *Hii, *Hip, *Hi ;
+    Long nf, f, nh, h1, h2, v, n1rows, m2, n2 ;
 
     // -------------------------------------------------------------------------
     // get the contents of the QR factorization
@@ -1147,8 +1143,8 @@ template <typename Entry> void spqr_private_Happly
     cholmod_l_free_dense (&Wdense, cc) ; \
     cholmod_l_free_dense (&Cdense, cc) ; \
     cholmod_l_free (maxfn, sizeof (Entry), H_Tau,   cc) ; \
-    cholmod_l_free (maxfn, sizeof (Int),   H_start, cc) ; \
-    cholmod_l_free (maxfn, sizeof (Int),   H_end,   cc) ; \
+    cholmod_l_free (maxfn, sizeof (Long),  H_start, cc) ; \
+    cholmod_l_free (maxfn, sizeof (Long),  H_end,   cc) ; \
 }
 
 // returns Y of size m-by-n, or NULL on failure
@@ -1165,8 +1161,8 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
 {
     cholmod_dense *Ydense, *Cdense, *Vdense, *Wdense, *Zdense ;
     Entry *X, *Y, *X1, *Y1, *Z1, *C, *V, *Z, *W, *H_Tau ;
-    Int *HPinv, *H_start, *H_end ;
-    Int i, k, mh, v, hchunk, ldx, m, n, maxfn, ok ;
+    Long *HPinv, *H_start, *H_end ;
+    Long i, k, mh, v, hchunk, ldx, m, n, maxfn, ok ;
 
     // -------------------------------------------------------------------------
     // get inputs
@@ -1177,7 +1173,7 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
     RETURN_IF_NULL (QR->QRnum, NULL) ;
     RETURN_IF_NULL (QR->QRnum->Hm, NULL) ;
     RETURN_IF_NULL (Xdense, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (Xdense, NULL) ;
     cc->status = CHOLMOD_OK ;
 
@@ -1260,8 +1256,8 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_qmult
     Wdense = NULL ;
 
     H_Tau   = (Entry *) cholmod_l_malloc (maxfn, sizeof (Entry), cc) ;
-    H_start = (Int *)   cholmod_l_malloc (maxfn, sizeof (Int),   cc) ;
-    H_end   = (Int *)   cholmod_l_malloc (maxfn, sizeof (Int),   cc) ;
+    H_start = (Long *)  cholmod_l_malloc (maxfn, sizeof (Long),  cc) ;
+    H_end   = (Long *)  cholmod_l_malloc (maxfn, sizeof (Long),  cc) ;
 
     if (!ok || Cdense == NULL || cc->status < CHOLMOD_OK)
     {
@@ -1503,7 +1499,7 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_qmult
     RETURN_IF_NULL_COMMON (NULL) ;
     RETURN_IF_NULL (QR, NULL) ;
     RETURN_IF_NULL (Xsparse, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (Xsparse, NULL) ;
     cc->status = CHOLMOD_OK ;
 
@@ -1591,16 +1587,15 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_min2norm
     RETURN_IF_NULL_COMMON (NULL) ;
     RETURN_IF_NULL (A, NULL) ;
     RETURN_IF_NULL (B, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (A, NULL) ;
     RETURN_IF_XTYPE_INVALID (B, NULL) ;
     cc->status = CHOLMOD_OK ;
 
     if (A->nrow < A->ncol)
     {
-#ifdef TIMING
-        double t0 = spqr_time ( ) ;
-#endif
+
+        double t0 = SuiteSparse_time ( ) ;
 
         // x=A\B, using a QR factorization of A'
         SuiteSparseQR_factorization <Entry> *QR ;
@@ -1617,11 +1612,9 @@ template <typename Entry> cholmod_dense *SuiteSparseQR_min2norm
         cholmod_l_free_dense (&Y, cc) ;
         spqr_freefac (&QR, cc) ;
 
-#ifdef TIMING
-        double t3 = spqr_time ( ) ;
+        double t3 = SuiteSparse_time ( ) ;
         double total_time = t3 - t0 ;
         cc->other1 [3] = total_time - cc->other1 [1] - cc->other1 [2] ;
-#endif
 
     }
     else
@@ -1676,16 +1669,14 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_min2norm    // returns X
     cholmod_common *cc
 )
 {
-#ifdef TIMING
-    double t0 = spqr_time ( ) ;
-#endif
+    double t0 = SuiteSparse_time ( ) ;
 
     cholmod_dense *Bdense, *Xdense ;
     cholmod_sparse *Xsparse = NULL ;
     RETURN_IF_NULL_COMMON (NULL) ;
     RETURN_IF_NULL (A, NULL) ;
     RETURN_IF_NULL (Bsparse, NULL) ;
-    Int xtype = spqr_type <Entry> ( ) ;
+    Long xtype = spqr_type <Entry> ( ) ;
     RETURN_IF_XTYPE_INVALID (A, NULL) ;
     RETURN_IF_XTYPE_INVALID (Bsparse, NULL) ;
     cc->status = CHOLMOD_OK ;
@@ -1701,11 +1692,9 @@ template <typename Entry> cholmod_sparse *SuiteSparseQR_min2norm    // returns X
         cc->status = CHOLMOD_OUT_OF_MEMORY ;
     }
 
-#ifdef TIMING
-    double t3 = spqr_time ( ) ;
+    double t3 = SuiteSparse_time ( ) ;
     double total_time = t3 - t0 ;
     cc->other1 [3] = total_time - cc->other1 [1] - cc->other1 [2] ;
-#endif
 
     return (Xsparse) ;
 }
